========
Property
========

The Property commands are used to create and manage reinforcements and to assign properties to a part.
(See also Material commands and Section commands.) The Property commands are methods of a Part object.

Create properties for Part
--------------------------

.. autoclass:: abaqus.Property.PropertyPart.PropertyPart
    :noindex:
    :members:

Object features
---------------

CompositeLayup
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Property.CompositeLayup.CompositeLayup
    :members:

    .. autoclasstoc::

CompositePly
~~~~~~~~~~~~

.. autoclass:: abaqus.Property.CompositePly.CompositePly
    :members:

    .. autoclasstoc::

CompositePlyArray
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Property.CompositePlyArray.CompositePlyArray
    :members:

    .. autoclasstoc::

MaterialOrientation
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Property.MaterialOrientation.MaterialOrientation
    :members:

    .. autoclasstoc::

MaterialOrientationArray
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Property.MaterialOrientationArray.MaterialOrientationArray
    :members:

    .. autoclasstoc::

PlyStackPlot
~~~~~~~~~~~~

.. autoclass:: abaqus.Property.PlyStackPlot.PlyStackPlot
    :members:

    .. autoclasstoc::

PropertyAssembly
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Property.PropertyAssembly.PropertyAssembly
    :members:

    .. autoclasstoc::

SectionAssignment
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Property.SectionAssignment.SectionAssignment
    :members:

    .. autoclasstoc::

SectionAssignmentArray
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Property.SectionAssignmentArray.SectionAssignmentArray
    :members:

    .. autoclasstoc::

